# Blobbit/Gloopy, a platformer video game
# Copyright (C) 2007  Christopher Allan Webber and Jeff Gibson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from pygame.rect import Rect
from pygame.surface import Surface

class Camera(object):
  def __init__(self, engine, width, height, initial_x=0, initial_y=0,
               controlling_sprite=None):
    self.rect = Rect(initial_x, initial_y, width, height)
    self.camera_surface = Surface((self.rect.width, self.rect.height)).convert()
    self.controlling_sprite = controlling_sprite
    self.engine = engine

  def draw_group(self, group):
    sprites = group.sprites()
    for spr in sprites:
      if spr.is_visible:
        group.spritedict[spr] = self.camera_surface.blit(spr.image,
                                                         spr.relative_rect(self))
    group.lostsprites = []

  def update(self):
    if self.controlling_sprite:
      self.rect.centerx = self.controlling_sprite.rect.centerx
      self.rect.centery = self.controlling_sprite.rect.centery

      #check to make sure not going out of range for...
      # ..top or bottom
      if self.rect.top < 0:
        self.rect.top = 0
      elif self.rect.bottom > self.engine.level.bottom_pixel:
        self.rect.bottom = self.engine.level.bottom_pixel
      # ..and left or right
      if self.rect.left < 0:
        self.rect.left = 0
      elif self.rect.right > self.engine.level.rightmost_pixel:
        self.rect.right = self.engine.level.rightmost_pixel

#   def draw(self, surface, sprite_group):
#      spritedict = self.spritedict
#      surface_blit = surface.blit
#      dirty = self.lostsprites
#      self.lostsprites = []
#      dirty_append = dirty.append
#      for s in self.sprites():
#          r = spritedict[s]
#          newrect = surface_blit(s.image, s.rect)
#          if r is 0:
#              dirty_append(newrect)
#          else:
#              if newrect.colliderect(r):
#                  dirty_append(newrect.union(r))
#              else:
#                  dirty_append(newrect)
#                  dirty_append(r)
#          spritedict[s] = newrect
#      return dirty

